@@ -1,35 +1,36 @@
-! $Xorg: xdm-conf.cpp,v 1.3 2000/08/17 19:54:17 cpqbld Exp $
-! $XdotOrg: $    
 !
 !
 !
 !
-! $XFree86: xc/programs/xdm/config/xdm-conf.cpp,v 1.10 2002/11/30 19:11:32 herrb Exp $
 !
 #ifndef XDMCONFIGDIR
 #define XDMCONFIGDIR XDMDIR
 #endif
+#ifndef XDMSCRIPTDIR
+#define XDMSCRIPTDIR XDMDIR
+#endif
+DisplayManager.authDir:	XDMXAUTHDIR
 DisplayManager.errorLogFile:	XDMLOGDIR/xdm.log
 DisplayManager.pidFile:		XDMPIDDIR/xdm.pid
 DisplayManager.keyFile:		XDMCONFIGDIR/xdm-keys
 DisplayManager.servers:		XDMCONFIGDIR/Xservers
 DisplayManager.accessFile:	XDMCONFIGDIR/Xaccess
 DisplayManager*resources:	XDMCONFIGDIR/Xresources
-DisplayManager.willing:		SU nobody -c XDMDIR/Xwilling
+DisplayManager.willing:		SU nobody -s /bin/sh -c XDMSCRIPTDIR/Xwilling
 ! All displays should use authorization, but we cannot be sure
 ! X terminals may not be configured that way, so they will require
 ! individual resource settings.
 DisplayManager*authorize:	true
 !
 DisplayManager*chooser:		CHOOSERPATH
-DisplayManager*startup:		XDMDIR/Xstartup
-DisplayManager*session:		XDMDIR/Xsession
-DisplayManager*reset:		XDMDIR/Xreset
+DisplayManager*startup:		XDMSCRIPTDIR/Xstartup
+DisplayManager*session:		XDMSCRIPTDIR/Xsession
+DisplayManager*reset:		XDMSCRIPTDIR/Xreset
 DisplayManager*authComplain:	true
 ! The following three resources set up display :0 as the console.
-DisplayManager._0.setup:	XDMDIR/Xsetup_0
-DisplayManager._0.startup:	XDMDIR/GiveConsole
-DisplayManager._0.reset:	XDMDIR/TakeConsole
+DisplayManager._0.setup:	XDMSCRIPTDIR/Xsetup_0
+DisplayManager._0.startup:	XDMSCRIPTDIR/GiveConsole
+DisplayManager._0.reset:	XDMSCRIPTDIR/TakeConsole
 #ifdef XPM
 DisplayManager*loginmoveInterval:	10
 #endif /* XPM */
