@@ -25,32 +25,27 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
+/*
+ * Copyright (c) 2006, Oracle and/or its affiliates. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the
- * "Software"), to deal in the Software without restriction, including
- * without limitation the rights to use, copy, modify, merge, publish,
- * distribute, and/or sell copies of the Software, and to permit persons
- * to whom the Software is furnished to do so, provided that the above
- * copyright notice(s) and this permission notice appear in all copies of
- * the Software and that both the above copyright notice(s) and this
- * permission notice appear in supporting documentation.
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
  *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
- * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
- * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
- * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
- * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
- * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
- * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ * The above copyright notice and this permission notice (including the next
+ * paragraph) shall be included in all copies or substantial portions of the
+ * Software.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale, use
- * or other dealings in this Software without prior written authorization
- * of the copyright holder.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 /*
@@ -77,12 +72,12 @@ from The Open Group.
 typedef void (*LoginFunc)(LoginWidget, LoginData *, int);
 
 typedef struct {
-    	char *		promptText;	/* Prompt displayed */
-    	const char *	defaultPrompt;	/* Default text for prompt */
-    	char *		valueText;	/* Value entered for prompt */
-   	size_t		valueTextMax;	/* Size of valueText buffer */
-    	int		valueShownStart;/* Amount of string shown if too */
-    	int		valueShownEnd;	/*  long to fit in field */
+	char *		promptText;	/* Prompt displayed */
+	const char *	defaultPrompt;	/* Default text for prompt */
+	char *		valueText;	/* Value entered for prompt */
+	size_t		valueTextMax;	/* Size of valueText buffer */
+	int		valueShownStart;/* Amount of string shown if too */
+	int		valueShownEnd;	/*  long to fit in field */
 	int		cursor;		/* current cursor position */
 	loginPromptState state;
 } loginPromptData;
@@ -114,9 +109,9 @@ typedef struct {
 	char		*unsecure_greet;/* message displayed when insecure */
 	char		*namePrompt;	/* name prompt */
 	char		*passwdPrompt;	/* password prompt */
-    	char		*failMsg;	/* failure message */
+	char		*failMsg;	/* failure message */
 	char		*fail;		/* current error message */
-    	char		*passwdChangeMsg; /* message when passwd expires */
+	char		*passwdChangeMsg; /* message when passwd expires */
 # ifndef USE_XFT
 	XFontStruct	*textFont;	/* font for text */
 	XFontStruct	*promptFont;	/* font for prompts */
@@ -124,7 +119,7 @@ typedef struct {
 	XFontStruct	*failFont;	/* font for failure message */
 # endif /* USE_XFT */
 	int		state;		/* state */
-    	int		activePrompt;	/* which prompt is active */
+	int		activePrompt;	/* which prompt is active */
 	int		failUp;		/* failure message displayed */
 	LoginData	data;		/* name/passwd */
 	char		*sessionArg;	/* argument passed to session */
@@ -135,9 +130,13 @@ typedef struct {
 	Boolean		allow_access;	/* disable access control on login */
 	Boolean		allow_null_passwd; /* allow null password on login */
 	Boolean		allow_root_login; /* allow root login */
+	/* option to display characters such as asterisks, i.e. '**...'
+	   for no-echo prompts like passwords */
+	Boolean		echo_passwd;
+	char *		echo_passwd_char;
 	XIC		xic;		/* input method of input context */
 	loginPromptData	prompts[NUM_PROMPTS];
-    	time_t 		msgTimeout;
+	time_t 		msgTimeout;
 
 # ifdef DANCING
 	/*caolan begin*/
